(ns puppetlabs.rbac.storage.permissioned
  "This namespace consists of all of the functions that should use
  authorization, properly wrapped and ready for use. All require a Shiro
  subject as their first argument."
  (:require [puppetlabs.rbac.ldap :as ldap]
            [puppetlabs.rbac.storage :as st]
            [puppetlabs.rbac.sync :as sn]
            [puppetlabs.rbac.storage.authorization :as authz]))

(defn get-groups
  ([subject db-spec]
   (authz/multiple-instances-check subject #'st/get-groups db-spec))
  ([subject db-spec ids]
   (authz/multiple-instances-check subject #'st/get-groups db-spec ids)))

(defn get-group [subject db-spec column value]
  (authz/single-instance-check subject #'st/get-group db-spec column value))

(defn import-group! [subject db-spec data]
  (authz/no-instance-check subject #'sn/create-group! db-spec data))

(defn update-group! [subject db-spec id data]
  (authz/update-group-check subject #'st/update-remote! db-spec id data))

(defn get-directory-settings [subject db-spec]
  (authz/no-instance-check subject #'st/get-directory-settings db-spec))

(defn update-directory-settings!
  "This function should not be used directly. Prefer the version that calls this
  in RbacService, as that version is able to refresh the Shiro realm with the new
  settings."
  [subject db-spec settings]
  (authz/no-instance-check subject #'st/update-directory-settings! db-spec settings))

(defn test-connection
  [subject settings]
  (authz/no-instance-check subject #'ldap/test-connection settings))
